@@ -281,7 +281,7 @@ gvc_combo_box_class_init (GvcComboBoxClass *klass)
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (GvcComboBoxClass, changing),
                               NULL, NULL,
-                              g_cclosure_marshal_VOID__VOID,
+                              g_cclosure_marshal_VOID__OBJECT,
                               G_TYPE_NONE,
                               1,
                               MATE_MIXER_TYPE_SWITCH_OPTION);
@@ -294,8 +294,7 @@ gvc_combo_box_class_init (GvcComboBoxClass *klass)
                               NULL, NULL,
                               g_cclosure_marshal_VOID__VOID,
                               G_TYPE_NONE,
-                              0,
-                              G_TYPE_NONE);
+                              0);
 
         g_type_class_add_private (klass, sizeof (GvcComboBoxPrivate));
 }
@@ -355,12 +354,8 @@ gvc_combo_box_init (GvcComboBox *combobox)
 
         combobox->priv->label = gtk_label_new (NULL);
 
-#if GTK_CHECK_VERSION (3, 16, 0)
         gtk_label_set_xalign (GTK_LABEL (combobox->priv->label), 0.0);
         gtk_label_set_yalign (GTK_LABEL (combobox->priv->label), 0.5);
-#else
-        gtk_misc_set_alignment (GTK_MISC (combobox->priv->label), 0.0, 0.5);
-#endif
         gtk_label_set_mnemonic_widget (GTK_LABEL (combobox->priv->label),
                                        combobox->priv->combobox);
 
@@ -373,7 +368,6 @@ gvc_combo_box_init (GvcComboBox *combobox)
                                        "text",
                                        COL_HUMAN_NAME);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
         combobox->priv->drop_box  = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
         combobox->priv->start_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
         combobox->priv->end_box   = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
@@ -385,11 +379,6 @@ gvc_combo_box_init (GvcComboBox *combobox)
                       NULL);
 
         gtk_combo_box_set_popup_fixed_width (GTK_COMBO_BOX (combobox->priv->combobox), FALSE);
-#else
-        combobox->priv->drop_box  = gtk_hbox_new (FALSE, 6);
-        combobox->priv->start_box = gtk_hbox_new (FALSE, 6);
-        combobox->priv->end_box   = gtk_hbox_new (FALSE, 6);
-#endif
 
         gtk_box_pack_start (GTK_BOX (combobox),
                             frame,
@@ -454,8 +443,6 @@ gvc_combo_box_new (MateMixerSwitch *swtch, const gchar *label)
         return g_object_new (GVC_TYPE_COMBO_BOX,
                              "switch", swtch,
                              "label", label,
-#if GTK_CHECK_VERSION (3, 0, 0)
                              "orientation", GTK_ORIENTATION_HORIZONTAL,
-#endif
                              NULL);
 }
